PackSuiteOptions

Struct PackSuiteOptions 

pub struct PackSuiteOptions {
    pub manifest_override: Option<PathBuf>,
    pub require_flows: bool,
    pub runtime_adapter: Option<Arc<dyn PackRuntimeAdapter>>,
    pub require_runtime_match: bool,
}
Configuration knobs for pack verification.

Fields

manifest_override: Option<PathBuf>

Optional manifest path override.

require_flows: bool

Require at least one flow to be exported.

runtime_adapter: Option<Arc<dyn PackRuntimeAdapter>>

Optional runtime adapter used to query the component for its exports.

require_runtime_match: bool

Fail verification if runtime exports diverge from the manifest.

Implementations

Source

impl PackSuiteOptions

pub fn verify_pack_exports( &self, component_path: impl AsRef<Path>, ) -> Result<PackReport>

Executes the pack export verification with custom options.

pub fn with_runtime_adapter<A>(self, adapter: A) -> Self
where A: PackRuntimeAdapter + 'static,

Convenience helper to configure a runtime adapter.

pub fn with_manifest_override(self, manifest: impl Into<PathBuf>) -> Self

Convenience helper to override the manifest discovery path.

pub fn allow_runtime_mismatch(self) -> Self

Allows diverging runtime exports without failing verification.